@@ -23,7 +23,14 @@
  *See COPYRIGHT file copyright information.
  */
 #include "nmv-terminal.h"
-#include <pty.h>
+#if !defined(__FreeBSD__)
+# include <pty.h>
+#else
+# include <sys/types.h>
+# include <sys/ioctl.h>
+# include <termios.h>
+# include <libutil.h>
+#endif
 #include <iostream>
 #include <gtkmm/bin.h>
 #include <gtkmm/main.h>
@@ -161,5 +168,12 @@ Terminal::slave_pts_name () const
     return result ;
 }
 
+void
+Terminal::modify_font (const Pango::FontDescription &font_desc)
+{
+    THROW_IF_FAIL (m_priv);
+    vte_terminal_set_font (m_priv->vte, font_desc.gobj());
+}
+
 NEMIVER_END_NAMESPACE(nemiver)
 
